@@ -404,3 +404,22 @@ class _SpanBertCorefLoader(ExtendedJavaWrapper):
     def __init__(self, path, jspark):
         super(_SpanBertCorefLoader, self).__init__(
             "com.johnsnowlabs.nlp.annotators.coref.SpanBertCorefModel.loadSavedModel", path, jspark)
+
+
+class _NerDLGraphBuilder(ExtendedJavaWrapper):
+    def __init__(self, dataset, input_col, label_col):
+        super(_NerDLGraphBuilder, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.ner.dl.NerDLApproach.getGraphParams",
+            dataset, input_col, label_col)
+
+
+class _ResourceHelper(ExtendedJavaWrapper):
+    def __init__(self, local_file, hdfs_file):
+        super(_ResourceHelper, self).__init__(
+            "com.johnsnowlabs.nlp.util.io.ResourceHelper.moveFile", local_file, hdfs_file)
+
+class _ViTForImageClassification(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_ViTForImageClassification, self).__init__(
+            "com.johnsnowlabs.nlp.annotators.cv.ViTForImageClassification.loadSavedModel", path,
+            jspark)
